==> jc-1.4.0.tar.gz: java/awt/geom/Ellipse2D__24Double.h <==
// public class java.awt.geom.Ellipse2D$Double

// class file dependencies
// @dep_class 718dd7c671fd5bb1 java_awt_geom_Ellipse2D
// @dep_class 1e61651a78531c80 java_awt_geom_Ellipse2D__24Double
// @dep_class bfc51dd0f2a7e666 java_awt_geom_RectangularShape
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_geom_Ellipse2D

#include "java/awt/geom/Ellipse2D.h"

#ifndef _JC_java_awt_geom_Ellipse2D__24Double_H_
#define _JC_java_awt_geom_Ellipse2D__24Double_H_

// Forward structure declarations
struct _jc_java_awt_geom_Rectangle2D$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_geom_Ellipse2D__24Double$sub_refs	_jc_java_awt_geom_Ellipse2D__24Double$sub_refs;
typedef struct _jc_java_awt_geom_Ellipse2D__24Double$sub_nonrefs	_jc_java_awt_geom_Ellipse2D__24Double$sub_nonrefs;
typedef struct _jc_java_awt_geom_Ellipse2D__24Double$refs	_jc_java_awt_geom_Ellipse2D__24Double$refs;
typedef struct _jc_java_awt_geom_Ellipse2D__24Double$nonrefs	_jc_java_awt_geom_Ellipse2D__24Double$nonrefs;
typedef struct _jc_java_awt_geom_Ellipse2D__24Double$object	_jc_java_awt_geom_Ellipse2D__24Double$object;

typedef const struct _jc_java_awt_geom_Ellipse2D__24Double$vmethods	_jc_java_awt_geom_Ellipse2D__24Double$vmethods;
typedef const struct _jc_java_awt_geom_Ellipse2D__24Double$vtable	_jc_java_awt_geom_Ellipse2D__24Double$vtable;
typedef const struct _jc_java_awt_geom_Ellipse2D__24Double$vtype	_jc_java_awt_geom_Ellipse2D__24Double$vtype;

// Constructors
extern void _jc_java_awt_geom_Ellipse2D__24Double$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *);
extern void _jc_java_awt_geom_Ellipse2D__24Double$method$_init$29e1c9b58296095b(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *, jdouble, jdouble, jdouble, jdouble);

// Virtual methods
extern struct _jc_java_awt_geom_Rectangle2D$object *_jc_java_awt_geom_Ellipse2D__24Double$method$getBounds2D$465501a912b32d22(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *);
extern jdouble _jc_java_awt_geom_Ellipse2D__24Double$method$getHeight$099466d7bee38f0e(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *);
extern jdouble _jc_java_awt_geom_Ellipse2D__24Double$method$getWidth$7f6d44448448d217(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *);
extern jdouble _jc_java_awt_geom_Ellipse2D__24Double$method$getX$da8367f71985b05b(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *);
extern jdouble _jc_java_awt_geom_Ellipse2D__24Double$method$getY$cea2a8c824df48e5(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *);
extern jboolean _jc_java_awt_geom_Ellipse2D__24Double$method$isEmpty$551bea84f4e0f0cb(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *);
extern void _jc_java_awt_geom_Ellipse2D__24Double$method$setFrame$845dc00ca29ef2db(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *, jdouble, jdouble, jdouble, jdouble);

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Double$method_info$getBounds2D$465501a912b32d22;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Double$method_info$getHeight$099466d7bee38f0e;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Double$method_info$getWidth$7f6d44448448d217;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Double$method_info$getX$da8367f71985b05b;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Double$method_info$getY$cea2a8c824df48e5;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Double$method_info$isEmpty$551bea84f4e0f0cb;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Double$method_info$setFrame$845dc00ca29ef2db;

// Virtual methods structure
struct _jc_java_awt_geom_Ellipse2D__24Double$vmethods {
	struct _jc_java_awt_geom_Rectangle2D$object	*(*getBounds2D$465501a912b32d22)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *);
	jdouble	(*getHeight$099466d7bee38f0e)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *);
	jdouble	(*getWidth$7f6d44448448d217)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *);
	jdouble	(*getX$da8367f71985b05b)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *);
	jdouble	(*getY$cea2a8c824df48e5)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *);
	jboolean	(*isEmpty$551bea84f4e0f0cb)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *);
	void	(*setFrame$845dc00ca29ef2db)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *, jdouble, jdouble, jdouble, jdouble);
};

// Vtable
struct _jc_java_awt_geom_Ellipse2D__24Double$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_RectangularShape$vmethods	java_awt_geom_RectangularShape;
	_jc_java_awt_geom_Ellipse2D$vmethods	java_awt_geom_Ellipse2D;
	_jc_java_awt_geom_Ellipse2D__24Double$vmethods	java_awt_geom_Ellipse2D__24Double;
};

// Vtype
struct _jc_java_awt_geom_Ellipse2D__24Double$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Ellipse2D__24Double$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Ellipse2D__24Double$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Ellipse2D__24Double$refs {
    _jc_java_awt_geom_Ellipse2D__24Double$sub_refs	java_awt_geom_Ellipse2D__24Double;
    _jc_java_awt_geom_Ellipse2D$sub_refs	java_awt_geom_Ellipse2D;
    _jc_java_awt_geom_RectangularShape$sub_refs	java_awt_geom_RectangularShape;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Ellipse2D__24Double$sub_nonrefs {
	jdouble	height;
	jdouble	width;
	jdouble	x;
	jdouble	y;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Ellipse2D__24Double$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_RectangularShape$sub_nonrefs	java_awt_geom_RectangularShape;
    _jc_java_awt_geom_Ellipse2D$sub_nonrefs	java_awt_geom_Ellipse2D;
    _jc_java_awt_geom_Ellipse2D__24Double$sub_nonrefs	java_awt_geom_Ellipse2D__24Double;
};

// Object instance structure
struct _jc_java_awt_geom_Ellipse2D__24Double$object {
	_jc_java_awt_geom_Ellipse2D__24Double$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Ellipse2D__24Double$vtype	*vtype;
	_jc_java_awt_geom_Ellipse2D__24Double$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Ellipse2D__24Double$vtype _jc_java_awt_geom_Ellipse2D__24Double$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Ellipse2D__24Double, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Ellipse2D__24Double$class_object;

#endif	/* _JC_java_awt_geom_Ellipse2D__24Double_H_ */

==> jc-1.4.6.tar.gz: java/awt/geom/Ellipse2D__24Double.h <==
// public class java.awt.geom.Ellipse2D$Double

// class file dependencies
// @dep_class 718dd7c671fd5bb1 java_awt_geom_Ellipse2D
// @dep_class 1e61651a78531c80 java_awt_geom_Ellipse2D__24Double
// @dep_class bfc51dd0f2a7e666 java_awt_geom_RectangularShape
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_geom_Ellipse2D

#include "java/awt/geom/Ellipse2D.h"

#ifndef _JC_java_awt_geom_Ellipse2D__24Double_H_
#define _JC_java_awt_geom_Ellipse2D__24Double_H_

// Forward structure declarations
struct _jc_java_awt_geom_Rectangle2D$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_geom_Ellipse2D__24Double$sub_refs	_jc_java_awt_geom_Ellipse2D__24Double$sub_refs;
typedef struct _jc_java_awt_geom_Ellipse2D__24Double$sub_nonrefs	_jc_java_awt_geom_Ellipse2D__24Double$sub_nonrefs;
typedef struct _jc_java_awt_geom_Ellipse2D__24Double$refs	_jc_java_awt_geom_Ellipse2D__24Double$refs;
typedef struct _jc_java_awt_geom_Ellipse2D__24Double$nonrefs	_jc_java_awt_geom_Ellipse2D__24Double$nonrefs;
typedef struct _jc_java_awt_geom_Ellipse2D__24Double$object	_jc_java_awt_geom_Ellipse2D__24Double$object;

typedef const struct _jc_java_awt_geom_Ellipse2D__24Double$vmethods	_jc_java_awt_geom_Ellipse2D__24Double$vmethods;
typedef const struct _jc_java_awt_geom_Ellipse2D__24Double$vtable	_jc_java_awt_geom_Ellipse2D__24Double$vtable;
typedef const struct _jc_java_awt_geom_Ellipse2D__24Double$vtype	_jc_java_awt_geom_Ellipse2D__24Double$vtype;

// Constructors
extern void _jc_java_awt_geom_Ellipse2D__24Double$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_geom_Ellipse2D__24Double$method$_init$29e1c9b58296095b(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *, jdouble, jdouble, jdouble, jdouble) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_geom_Rectangle2D$object *_jc_java_awt_geom_Ellipse2D__24Double$method$getBounds2D$465501a912b32d22(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *) _JC_JCNI_ATTR;
extern jdouble _jc_java_awt_geom_Ellipse2D__24Double$method$getHeight$099466d7bee38f0e(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *) _JC_JCNI_ATTR;
extern jdouble _jc_java_awt_geom_Ellipse2D__24Double$method$getWidth$7f6d44448448d217(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *) _JC_JCNI_ATTR;
extern jdouble _jc_java_awt_geom_Ellipse2D__24Double$method$getX$da8367f71985b05b(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *) _JC_JCNI_ATTR;
extern jdouble _jc_java_awt_geom_Ellipse2D__24Double$method$getY$cea2a8c824df48e5(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_geom_Ellipse2D__24Double$method$isEmpty$551bea84f4e0f0cb(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_geom_Ellipse2D__24Double$method$setFrame$845dc00ca29ef2db(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *, jdouble, jdouble, jdouble, jdouble) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Double$method_info$getBounds2D$465501a912b32d22;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Double$method_info$getHeight$099466d7bee38f0e;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Double$method_info$getWidth$7f6d44448448d217;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Double$method_info$getX$da8367f71985b05b;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Double$method_info$getY$cea2a8c824df48e5;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Double$method_info$isEmpty$551bea84f4e0f0cb;
extern _jc_method _jc_java_awt_geom_Ellipse2D__24Double$method_info$setFrame$845dc00ca29ef2db;

// Virtual methods structure
struct _jc_java_awt_geom_Ellipse2D__24Double$vmethods {
	struct _jc_java_awt_geom_Rectangle2D$object	*(*getBounds2D$465501a912b32d22)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *) _JC_JCNI_ATTR;
	jdouble	(*getHeight$099466d7bee38f0e)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *) _JC_JCNI_ATTR;
	jdouble	(*getWidth$7f6d44448448d217)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *) _JC_JCNI_ATTR;
	jdouble	(*getX$da8367f71985b05b)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *) _JC_JCNI_ATTR;
	jdouble	(*getY$cea2a8c824df48e5)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *) _JC_JCNI_ATTR;
	jboolean	(*isEmpty$551bea84f4e0f0cb)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *) _JC_JCNI_ATTR;
	void	(*setFrame$845dc00ca29ef2db)(_jc_env *, struct _jc_java_awt_geom_Ellipse2D__24Double$object *, jdouble, jdouble, jdouble, jdouble) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_geom_Ellipse2D__24Double$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_geom_RectangularShape$vmethods	java_awt_geom_RectangularShape;
	_jc_java_awt_geom_Ellipse2D$vmethods	java_awt_geom_Ellipse2D;
	_jc_java_awt_geom_Ellipse2D__24Double$vmethods	java_awt_geom_Ellipse2D__24Double;
};

// Vtype
struct _jc_java_awt_geom_Ellipse2D__24Double$vtype {
	_jc_type			type;
	_jc_java_awt_geom_Ellipse2D__24Double$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_geom_Ellipse2D__24Double$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_geom_Ellipse2D__24Double$refs {
    _jc_java_awt_geom_Ellipse2D__24Double$sub_refs	java_awt_geom_Ellipse2D__24Double;
    _jc_java_awt_geom_Ellipse2D$sub_refs	java_awt_geom_Ellipse2D;
    _jc_java_awt_geom_RectangularShape$sub_refs	java_awt_geom_RectangularShape;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_geom_Ellipse2D__24Double$sub_nonrefs {
	jdouble	height;
	jdouble	width;
	jdouble	x;
	jdouble	y;
};

// Non-reference instance fields (object)
struct _jc_java_awt_geom_Ellipse2D__24Double$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_geom_RectangularShape$sub_nonrefs	java_awt_geom_RectangularShape;
    _jc_java_awt_geom_Ellipse2D$sub_nonrefs	java_awt_geom_Ellipse2D;
    _jc_java_awt_geom_Ellipse2D__24Double$sub_nonrefs	java_awt_geom_Ellipse2D__24Double;
};

// Object instance structure
struct _jc_java_awt_geom_Ellipse2D__24Double$object {
	_jc_java_awt_geom_Ellipse2D__24Double$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_geom_Ellipse2D__24Double$vtype	*vtype;
	_jc_java_awt_geom_Ellipse2D__24Double$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_geom_Ellipse2D__24Double$vtype _jc_java_awt_geom_Ellipse2D__24Double$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_geom_Ellipse2D__24Double, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_geom_Ellipse2D__24Double$class_object;

#endif	/* _JC_java_awt_geom_Ellipse2D__24Double_H_ */
